@@ -14,6 +14,7 @@
         *confess = \&Mite::Shim::confess;
         *croak   = \&Mite::Shim::croak;
         *false   = \&Mite::Shim::false;
+        *guard   = \&Mite::Shim::guard;
         *lazy    = \&Mite::Shim::lazy;
         *ro      = \&Mite::Shim::ro;
         *rw      = \&Mite::Shim::rw;
@@ -81,6 +82,7 @@
 
     sub __META__ {
         no strict 'refs';
+        no warnings 'once';
         my $class = shift;
         $class = ref($class) || $class;
         my $linear_isa = mro::get_linear_isa($class);
